@@ -1,6 +1,6 @@
 /*
 Weborf
-Copyright (C) 2010-2018  Salvo "LtWorf" Tomaselli
+Copyright (C) 2010-2019  Salvo "LtWorf" Tomaselli
 
 Weborf is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ weborf_configuration_t weborf_conf = {
     .tar_directory=false,
     .is_inetd=false,
     .virtual_host = false,
-    .exec_script = true,
+    .exec_script = false,
     .ip = NULL,
     .port = PORT,
     .basedir=BASEDIR,
@@ -115,14 +115,18 @@ static void configuration_set_default_index() {
 }
 
 static void configuration_set_cgi(char *optarg) {
+    if (!optarg || strlen(optarg) == 0) {
+        weborf_conf.cgi_paths.len = 0; //count of indexes
+        return;
+    }
     int i = 0;
     weborf_conf.cgi_paths.len = 1; //count of indexes
     weborf_conf.cgi_paths.data[0] = optarg; //1st one points to begin of param
-    while (optarg[i++] != 0) { //Reads the string
+    while (optarg[++i] != 0) { //Reads the string
         if (optarg[i] == ',') {
-            optarg[i++] = 0; //Nulling the comma
+            optarg[i] = 0; //Nulling the comma
             //Increasing counter and making next item point to char after the comma
-            weborf_conf.cgi_paths.data[weborf_conf.cgi_paths.len++] = &optarg[i];
+            weborf_conf.cgi_paths.data[weborf_conf.cgi_paths.len++] = &optarg[i + 1];
             if (weborf_conf.cgi_paths.len == MAXINDEXCOUNT) {
                 fprintf(stderr, "Too many cgis, change MAXINDEXCOUNT in options.h to allow more\n");
                 syslog(LOG_ERR, "Too many cgis, change MAXINDEXCOUNT in options.h to allow more\n");
@@ -131,8 +135,19 @@ static void configuration_set_cgi(char *optarg) {
         }
     }
 
+    if (weborf_conf.cgi_paths.len % 2 == 1) {
+        fprintf(stderr, "--cgi components must be an even number\n");
+        syslog(LOG_ERR, "--cgi components must be an even number\n");
+        exit(6);
+    }
+
     for (i=0; i<weborf_conf.cgi_paths.len; i++) {
         weborf_conf.cgi_paths.data_l[i]=strlen(weborf_conf.cgi_paths.data[i]);
+        if (i % 2 == 0 && weborf_conf.cgi_paths.data_l[i] == 0) {
+            fprintf(stderr, "file extension can't have length 0\n");
+            syslog(LOG_ERR, "file extension can't have length 0\n");
+            exit(6);
+        }
     }
 
 }
@@ -225,7 +240,7 @@ void configuration_load(int argc, char *argv[]) {
         {"auth", required_argument, 0, 'a'},
         {"virtual", required_argument, 0, 'V'},
         {"moo", no_argument, 0, 'M'},
-        {"noexec", no_argument, 0, 'x'},
+        {"yesexec", no_argument, 0, 'Y'},
         {"cgi", required_argument, 0, 'c'},
         {"cache", required_argument, 0, 'C'},
         {"mime", no_argument,0,'m'},
@@ -245,7 +260,7 @@ void configuration_load(int argc, char *argv[]) {
         c = getopt_long(
             argc,
             argv,
-            "ktTMmvhp:i:I:u:g:dxb:a:V:c:C:S:",
+            "ktTMmvhp:i:I:u:g:dYb:a:V:c:C:S:",
             long_options,
             &option_index
         );
@@ -282,8 +297,8 @@ void configuration_load(int argc, char *argv[]) {
         case 'b':
             configuration_set_basedir(optarg);
             break;
-        case 'x':
-            weborf_conf.exec_script = false;
+        case 'Y':
+            weborf_conf.exec_script = true;
             break;
         case 'v':   //Show version and exit
             version();
